@@ -50,7 +50,7 @@ def get_fleur_modes(xmltree, schema_dict, logger=None):
     from masci_tools.util.xml.common_functions import clear_xml
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -86,6 +86,23 @@ def get_fleur_modes(xmltree, schema_dict, logger=None):
     else:
         fleur_modes['force_theorem'] = False
 
+    if schema_dict.inp_version >= (0, 33):
+        cf_coeff = any(
+            evaluate_attribute(root,
+                               schema_dict,
+                               'potential',
+                               contains='cFCoeffs',
+                               logger=logger,
+                               list_return=True,
+                               optional=True))
+        cf_coeff = cf_coeff or any(
+            evaluate_attribute(
+                root, schema_dict, 'chargeDensity', contains='cFCoeffs', logger=logger, list_return=True,
+                optional=True))
+        fleur_modes['cf_coeff'] = cf_coeff
+    else:
+        fleur_modes['cf_coeff'] = False
+
     fleur_modes['film'] = tag_exists(root, schema_dict, 'filmPos', logger=logger)
     fleur_modes['ldau'] = tag_exists(root, schema_dict, 'ldaU', contains='species', logger=logger)
     fleur_modes['dos'] = evaluate_attribute(root, schema_dict, 'dos', constants=constants, logger=logger)
@@ -123,7 +140,7 @@ def get_nkpts(xmltree, schema_dict, logger=None):
     from masci_tools.util.xml.common_functions import clear_xml
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -173,7 +190,7 @@ def get_nkpts_max4(xmltree, schema_dict, logger=None):
     import warnings
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -251,7 +268,7 @@ def get_cell(xmltree, schema_dict, logger=None):
     import numpy as np
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -335,7 +352,7 @@ def get_parameter_data(xmltree, schema_dict, inpgen_ready=True, write_ids=True,
     ########
     parameters = {}
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -519,7 +536,7 @@ def get_structure_data(xmltree, schema_dict, logger=None):
     from masci_tools.io.common_functions import rel_to_abs, rel_to_abs_f
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -644,7 +661,7 @@ def get_kpoints_data(xmltree, schema_dict, name=None, logger=None):
     from masci_tools.util.xml.converters import convert_xml_attribute
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -733,7 +750,7 @@ def get_kpoints_data_max4(xmltree, schema_dict, logger=None):
     from masci_tools.util.xml.converters import convert_xml_attribute
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
@@ -802,7 +819,7 @@ def get_relaxation_information(xmltree, schema_dict, logger=None):
     from masci_tools.util.xml.common_functions import clear_xml
 
     if isinstance(xmltree, etree._ElementTree):
-        xmltree = clear_xml(xmltree)
+        xmltree, _ = clear_xml(xmltree)
         root = xmltree.getroot()
     else:
         root = xmltree
